@@ -9,7 +9,7 @@ extern "C" {
 #include <stdlib.h>
 
 #define TERMKEY_VERSION_MAJOR 0
-#define TERMKEY_VERSION_MINOR 13
+#define TERMKEY_VERSION_MINOR 14
 
 #define TERMKEY_CHECK_VERSION \
         termkey_check_version(TERMKEY_VERSION_MAJOR, TERMKEY_VERSION_MINOR)
@@ -136,7 +136,7 @@ typedef struct {
   char utf8[7];
 } TermKeyKey;
 
-typedef struct _TermKey TermKey;
+typedef struct TermKey TermKey;
 
 enum {
   TERMKEY_FLAG_NOINTERPRET = 1 << 0, /* Do not interpret C0//DEL codes if possible */
@@ -161,6 +161,10 @@ TermKey *termkey_new_abstract(const char *term, int flags);
 void     termkey_free(TermKey *tk);
 void     termkey_destroy(TermKey *tk);
 
+int termkey_start(TermKey *tk);
+int termkey_stop(TermKey *tk);
+int termkey_is_started(TermKey *tk);
+
 int termkey_get_fd(TermKey *tk);
 
 int  termkey_get_flags(TermKey *tk);
